/*******************************************************************************
 * Copyright (c) 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.target.internal.webdav;

import java.net.UnknownHostException;
import java.util.ResourceBundle;

import org.eclipse.core.runtime.*;
import org.eclipse.ui.plugin.AbstractUIPlugin;
import org.eclipse.webdav.internal.kernel.SystemException;
import org.eclipse.webdav.internal.kernel.WebDAVException;
import org.osgi.framework.BundleContext;

/**
 * The main plugin class to be used in the desktop.
 */
public class WebdavPlugin extends AbstractUIPlugin {
	//The shared instance.
	private static WebdavPlugin plugin;
	//Resource bundle.
	private ResourceBundle resourceBundle;
	
	public static final String ID = "org.eclipse.target.webdav"; //$NON-NLS-1$
	public static final String SITE_TYPE_ID = ID + ".site"; //$NON-NLS-1$
	
	/**
	 * The constructor.
	 */
	public WebdavPlugin() {
		plugin = this;
	}

	/**
	 * This method is called upon plug-in activation
	 */
	public void start(BundleContext context) throws Exception {
		super.start(context);
		Policy.localize("org.eclipse.target.internal.webdav.messages"); //$NON-NLS-1$
	}

	/**
	 * This method is called when the plug-in is stopped
	 */
	public void stop(BundleContext context) throws Exception {
		super.stop(context);
	}

	/**
	 * Returns the shared instance.
	 */
	public static WebdavPlugin getDefault() {
		return plugin;
	}
	
	public static void log(CoreException e) {
		log (e.getMessage(), e);
	}

	public static void log(String string, CoreException e) {
		getDefault().getLog().log(new Status(e.getStatus().getCode(), ID, 0, string, e));
	}
	
	/*
	 * Static helper methods for creating exceptions
	 */
	public static CoreException wrapException(Exception e) {
		if(e instanceof SystemException)
			return wrapException((SystemException) e);
		if(e instanceof WebDAVException)
			return wrapException((WebDAVException) e);
			
		return new CoreException(new Status(IStatus.ERROR, ID, 0, e.getMessage() != null ? e.getMessage() : "",	e)); //$NON-NLS-1$
	}

	public static CoreException wrapException(WebDAVException e) {
		int statusCode = e.getStatusCode();
		IStatus status = new Status(IStatus.ERROR, ID, statusCode, Policy.bind("plugin.davStatusError", String.valueOf(statusCode), e.getMessage()), e); //$NON-NLS-1$
		return new CoreException(status);
	}
	
	//Workaround for bug id=17996
	public static CoreException wrapException(SystemException e) {
		Exception we = e.getWrappedException();
		String message;
		if(we instanceof UnknownHostException) {
			message = Policy.bind("TeamWebDavPlugin.unknownHost"); //$NON-NLS-1$
		} else {
			message = we.getMessage();
		}
		return new CoreException(new Status(IStatus.ERROR, ID, 0, message, e));
	}
}
